@@ -17,8 +17,9 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#  version: 20220815134637
+#  version: 20220817153031
 
+import logging
 import re
 import mariadb
 from datetime import datetime, timedelta
@@ -151,7 +152,6 @@ class MeasurementDatabase:
             )
             rows = cursor.fetchall()
         else:
-            print("timestamps", starttime, endtime)
             cursor = self.connection.cursor()
             cursor.execute(
                 f"""SELECT Timestamp, Stationid, Temperature, Humidity
@@ -174,7 +174,9 @@ class MeasurementDatabase:
 
         return rows
 
-    def retrieveLastMeasurement(self, stationid, _names=None, _unique_stations=None):
+    def retrieveLastMeasurement(
+        self, stationid=None, _names=None, _unique_stations=None
+    ):
         """
         Return the last measurement data for a station or all stations.
 
@@ -184,14 +186,14 @@ class MeasurementDatabase:
         Returns:
             list: a list of dict objects, one for each station
         """
-        print(stationid, _names, _unique_stations)
+        logging.debug("retrieveLastMeasurement", stationid, _names, _unique_stations)
         if _names is None:
             _names = {nm[0]: nm[1] for nm in self.names("*")}
 
         if _unique_stations is None:
             _unique_stations = self.uniqueStations()
 
-        if stationid == "*":
+        if stationid is None:
             rows = []
             for unique_station in _unique_stations:
                 rows.extend(
@@ -223,13 +225,6 @@ class MeasurementDatabase:
             ]
         return rows
 
-    def retrieveMeasurementsLast24Hours(self, stationid):
-        ltz = tz.tzlocal()
-        d = timedelta(hours=24)
-        end = datetime.now(tz=ltz)
-        start = end - d
-        return self.retrieveMeasurements(stationid, start, end)
-
     def uniqueStations(self):
         conn = self.connection
         cursor = conn.cursor()
