@@ -17,7 +17,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#  version: 20220815140019
+#  version: 20220817152213
 
 from json import dumps
 import re
@@ -26,6 +26,7 @@ from datetime import datetime, timedelta
 from dateutil import tz
 from http import HTTPStatus
 from http.server import BaseHTTPRequestHandler, ThreadingHTTPServer
+import logging
 
 from .Database import Measurement
 from .Graph import graph
@@ -50,11 +51,11 @@ class InterceptorHandlerFactory:
                 re.IGNORECASE,
             )
             htmlpattern = re.compile(
-                r"^/html\?id=(?P<stationid>[a-z01-9-]+)$",
+                r"^/html(\?id=(?P<stationid>[a-z01-9-]+))?$",
                 re.IGNORECASE,
             )
             jsonpattern = re.compile(
-                r"^/json\?id=(?P<stationid>[a-z01-9-]+)$",
+                r"^/json(\?id=(?P<stationid>[a-z01-9-]+))?$",
                 re.IGNORECASE,
             )
             namespattern = re.compile(
@@ -63,9 +64,9 @@ class InterceptorHandlerFactory:
             )
 
             def do_GET(self):
-                print(self.path, flush=True)
-                if m := re.match(self.querypattern, self.path):
-                    try:
+                logging.info(self.path)
+                try:
+                    if m := re.match(self.querypattern, self.path):
                         measurement = Measurement(
                             m.group("stationid"),
                             m.group("temperature"),
@@ -73,11 +74,7 @@ class InterceptorHandlerFactory:
                         )
                         db.storeMeasurement(measurement)
                         self.send_response(HTTPStatus.OK)
-                    except Exception as e:
-                        print(e)
-                        self.send_response(HTTPStatus.INTERNAL_SERVER_ERROR)
-                elif m := re.match(self.graphpattern, self.path):
-                    try:
+                    elif m := re.match(self.graphpattern, self.path):
                         now = datetime.now(tz=tz.tzlocal())
                         yesterday = now - timedelta(1)
                         f = IO(b"")
@@ -89,12 +86,8 @@ class InterceptorHandlerFactory:
                         self.end_headers()
                         self.wfile.write(png)
                         f.close()
-                    except Exception as e:
-                        print(e)
-                        self.send_response(HTTPStatus.INTERNAL_SERVER_ERROR)
-                elif m := re.match(self.htmlpattern, self.path):
-                    try:
-                        ms = db.retrieveLastMeasurement("*")
+                    elif m := re.match(self.htmlpattern, self.path):
+                        ms = db.retrieveLastMeasurement(m.group("stationid"))
                         mdivs = "\n".join(
                             f"""
                             <div class="measurement{' late' if m['deltat'].total_seconds()>24*3600 else ''}" id="{m["stationid"]}">
@@ -115,7 +108,8 @@ class InterceptorHandlerFactory:
                         .hum {float:left; font-size:12pt;}
                         .late { background-color:red; }
                         """
-                        html = bytes(f"""<html>
+                        html = bytes(
+                            f"""<html>
                         <head><meta charset="UTF-8"><meta http-equiv="refresh" content="300"><title>Temperatuur binnen</title>
                         <style>{style}</style>
                         </head>
@@ -126,19 +120,20 @@ class InterceptorHandlerFactory:
                         </body>
                         <script>document.querySelectorAll("[data-time]").forEach(function(e){{d=new Date(e.getAttribute("data-time"));e.innerHTML=d.getHours() + ":" + d.getMinutes().toString().padStart(2, '0')}})</script>
                         </html>
-                        """, "UTF-8")
+                        """,
+                            "UTF-8",
+                        )
                         self.send_response(HTTPStatus.OK)
                         self.send_header("Content-type", "text/html")
                         self.send_header("Content-Length", str(len(html)))
                         self.end_headers()
                         self.wfile.write(html)
-                    except Exception as e:
-                        print(e)
-                        self.send_response(HTTPStatus.INTERNAL_SERVER_ERROR)
-                elif m := re.match(self.jsonpattern, self.path):
-                    try:
+                    elif m := re.match(self.jsonpattern, self.path):
                         json = bytes(
-                            dumps(db.retrieveLastMeasurement("*"), cls=DatetimeEncoder),
+                            dumps(
+                                db.retrieveLastMeasurement(m.group("stationid")),
+                                cls=DatetimeEncoder,
+                            ),
                             encoding="UTF-8",
                         )
                         self.send_response(HTTPStatus.OK)
@@ -146,11 +141,7 @@ class InterceptorHandlerFactory:
                         self.send_header("Content-Length", str(len(json)))
                         self.end_headers()
                         self.wfile.write(json)
-                    except Exception as e:
-                        print(e)
-                        self.send_response(HTTPStatus.INTERNAL_SERVER_ERROR)
-                elif m := re.match(self.namespattern, self.path):
-                    try:
+                    elif m := re.match(self.namespattern, self.path):
                         if not self.path.startswith("/names"):
                             stationid = m.group("stationid")
                             name = m.group("name")
@@ -168,11 +159,11 @@ class InterceptorHandlerFactory:
                         self.send_header("Content-Length", str(len(html)))
                         self.end_headers()
                         self.wfile.write(bytes(html, "UTF-8"))
-                    except Exception as e:
-                        print(e)
-                        self.send_response(HTTPStatus.INTERNAL_SERVER_ERROR)
-                else:
-                    self.send_response(HTTPStatus.FORBIDDEN)
+                    else:
+                        self.send_response(HTTPStatus.FORBIDDEN)
+                except Exception as e:
+                    logging.exception(e)
+                    self.send_response(HTTPStatus.INTERNAL_SERVER_ERROR)
                 self.end_headers()
 
         return InterceptorHandler
