@@ -191,7 +191,7 @@ class TestInterceptor:
                         print(captured.out)
                         assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
 
-    def test_GET_HTML(self, database, capsys):
+    def test_GET_HTML_all(self, database, capsys):
         stationid = "htmlid-123456"
         interceptorhandler = InterceptorHandlerFactory.getHandler(database)
 
@@ -200,6 +200,32 @@ class TestInterceptor:
         )  # without a stationid mapping we never get anything back
         start = datetime.now()
         database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(b"/html")
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
+
+    def test_GET_HTML_specific(self, database, capsys):
+        stationid = "htmlid-333333"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "htmlroom2"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
         with mock.patch.object(interceptorhandler, "finish", finish):
             with mock.patch.object(
                 interceptorhandler, "date_time_string", date_time_string
@@ -219,7 +245,38 @@ class TestInterceptor:
                         print(captured.out)
                         assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
 
-    def test_GET_JSON(self, database, capsys):
+    def test_GET_HTML_fail(self, database, capsys):
+        stationid = "htmlid-666666"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "htmlroom3"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(
+                            b"/html?stationid=%s" % bytes(stationid, "UTF-8")
+                        )
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert (
+                            ihinstance.wfile.getvalue()[:22]
+                            == b"HTTP/1.0 403 Forbidden"
+                        )
+
+    def test_GET_JSON_all(self, database, capsys):
         stationid = "jsonid-123456"
         interceptorhandler = InterceptorHandlerFactory.getHandler(database)
 
@@ -228,6 +285,32 @@ class TestInterceptor:
         )  # without a stationid mapping we never get anything back
         start = datetime.now()
         database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(b"/json")
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
+
+    def test_GET_JSON_specific(self, database, capsys):
+        stationid = "jsonid-333333"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "json room2"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
         with mock.patch.object(interceptorhandler, "finish", finish):
             with mock.patch.object(
                 interceptorhandler, "date_time_string", date_time_string
@@ -247,6 +330,37 @@ class TestInterceptor:
                         print(captured.out)
                         assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
 
+    def test_GET_JSON_fail(self, database, capsys):
+        stationid = "jsonid-666"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "json room3"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(
+                            b"/json?stationid=%s" % bytes(stationid, "UTF-8")
+                        )
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert (
+                            ihinstance.wfile.getvalue()[:22]
+                            == b"HTTP/1.0 403 Forbidden"
+                        )
+
     def test_GET_NAME(self, database, capsys):
         stationid = "newname-123456"
         name = "NewName"
